# pytrad
Python translation (and extension) of the Tetrad java code.

This branch is for organizing. Please feel free to modify anything if you think the organization could be improved, or you would like to integrate/develop any functions/tests.
